@@ -1,7 +1,7 @@
 #include "mainwindow.h"
 #include "../shared/transfer.h"
 #include "../shared/session.h"
-#include "../shared/utils.h"
+#include "../shared/definitions.h"
 #include "../dbus/dbusservice.h"
 #include "../dbus/dbusserviceadaptor.h"
 #include <QApplication>
@@ -10,7 +10,7 @@ int main(int argc, char *argv[])
 {
     QApplication app(argc, argv);
     app.setApplicationName("QDL");
-    app.setApplicationVersion(Utils::versionNumberString());
+    app.setApplicationVersion(VERSION_NUMBER);
     app.setWindowIcon(QIcon::fromTheme("qdl"));
     app.setQuitOnLastWindowClosed(false);
 
