@@ -1,6 +1,6 @@
 #include "mainwindow.h"
 #include "../shared/transfer.h"
-#include "../shared/utils.h"
+#include "../shared/definitions.h"
 #include "../shared/session.h"
 #include <QApplication>
 
@@ -8,7 +8,7 @@ int main(int argc, char *argv[])
 {
     QApplication app(argc, argv);
     app.setApplicationName("QDL");
-    app.setApplicationVersion(Utils::versionNumberString());
+    app.setApplicationVersion(VERSION_NUMBER);
 
     qRegisterMetaType< QList<Transfer*> >("QList<Transfer*>");
 
