@@ -168,9 +168,7 @@ void Connection::onMetaDataChanged() {
         qDebug() << "Reported size:" << size;
         this->setContentRangeEnd(size);
 
-        QString fileName = QString(m_reply->rawHeader("Content-Disposition"));
-        fileName = fileName.mid(fileName.lastIndexOf("filename=") + 1);
-        fileName = fileName.left(fileName.lastIndexOf(';')).remove(QRegExp("\'|\""));
+        QString fileName = QString(m_reply->rawHeader("Content-Disposition")).section("filename=", -1).section(';', 0, 0).remove(QRegExp("\'|\""));
 
         MetaInfo info;
         info.size = size;
