@@ -84,9 +84,7 @@ void UrlChecker::checkFileDownload() {
         case 201:
         case 206:
         {
-            QString fileName = QString(reply->rawHeader("Content-Disposition"));
-            fileName = fileName.mid(fileName.lastIndexOf("filename=") + 1);
-            fileName = fileName.left(fileName.lastIndexOf(';')).remove(QRegExp("\'|\""));
+            QString fileName = QString(reply->rawHeader("Content-Disposition")).section("filename=", -1).section(';', 0, 0).remove(QRegExp("\'|\""));
 
             if (fileName.isEmpty()) {
                 fileName = reply->request().url().toString().section('/', -1);
